@@ -1,5 +1,5 @@
 import vapoursynth as vs
-from vsexprtools.util import PlanesT, norm_expr_planes, normalise_planes
+from vsexprtools import PlanesT, norm_expr_planes, normalise_planes
 from vskernels import Catrom, Kernel, Spline144
 from vsmask.edge import EdgeDetect, ScharrTCanny
 from vsrgtools import RepairMode, box_blur, contrasharpening_median, median_clips, repair
@@ -9,6 +9,10 @@ from .abstract import SingleRater, SuperSampler
 from .antialiasers import Eedi3SR, Nnedi3SR, Nnedi3SS
 from .enums import AADirection
 
+__all__ = [
+    'upscaled_sraa', 'transpose_aa', 'clamp_aa', 'masked_clamp_aa', 'fine_aa'
+]
+
 core = vs.core
 
 
